[前][次][番号順一覧][スレッド一覧]

ruby-changes:70631

From: Takashi <ko1@a...>
Date: Tue, 28 Dec 2021 15:31:14 +0900 (JST)
Subject: [ruby-changes:70631] 3cd1731920 (master): Skip testing --enable-all in MinGW for now

https://git.ruby-lang.org/ruby.git/commit/?id=3cd1731920

From 3cd1731920c4fc038870e85dc8c9abf5739fbf71 Mon Sep 17 00:00:00 2001
From: Takashi Kokubun <takashikkbn@g...>
Date: Mon, 27 Dec 2021 22:28:15 -0800
Subject: Skip testing --enable-all in MinGW for now

If we don't intend to support this platform, we should probably enable
MJIT for MinGW. However, since the code for https://bugs.ruby-lang.org/issues/18439
is in place, I'm adjusting the test for it in the meantime.

following up https://github.com/ruby/ruby/pull/5363
---
 spec/ruby/command_line/feature_spec.rb | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/spec/ruby/command_line/feature_spec.rb b/spec/ruby/command_line/feature_spec.rb
index 1a9ea925c98..4a24cc6795d 100644
--- a/spec/ruby/command_line/feature_spec.rb
+++ b/spec/ruby/command_line/feature_spec.rb
@@ -43,7 +43,9 @@ describe "The --enable and --disable flags" do https://github.com/ruby/ruby/blob/trunk/spec/ruby/command_line/feature_spec.rb#L43
     ruby_exe("p 'foo'.frozen?", options: "--disable-frozen-string-literal").chomp.should == "false"
   end
 
-  platform_is_not :darwin do # frequently hangs for >60s on GitHub Actions macos-latest
+  # frequently hangs for >60s on GitHub Actions macos-latest
+  # MinGW's YJIT support seems broken
+  platform_is_not :darwin, :mingw do
     it "can be used with all for enable" do
       e = "p [defined?(Gem), defined?(DidYouMean), $VERBOSE, 'foo'.frozen?]"
       env = {'RUBYOPT' => '-w'}
-- 
cgit v1.2.1


--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]